==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/ComponentStatus.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** ComponentStatus (and ComponentStatusList) holds the cluster validation info. Deprecated: This API is deprecated in v1.19+ */
final case class ComponentStatus(
  conditions : Option[Seq[io.k8s.api.core.v1.ComponentCondition]] = None,
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("", "ComponentStatus", "v1")


  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.api.core.v1.ComponentCondition]) : ComponentStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.api.core.v1.ComponentCondition*) : ComponentStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.api.core.v1.ComponentCondition] => Seq[io.k8s.api.core.v1.ComponentCondition]) : ComponentStatus = copy(conditions = conditions.map(f))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : ComponentStatus = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : ComponentStatus = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = ComponentStatus.encoder[T].apply(this)
}

object ComponentStatus {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.ComponentStatus, T] = new Encoder[io.k8s.api.core.v1.ComponentStatus, T] {
        def apply(o: io.k8s.api.core.v1.ComponentStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("conditions", o.conditions)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ComponentStatus] = new Decoder[T, ComponentStatus] {
      def apply(t: T): Either[String, ComponentStatus] = for {
          obj <- ObjectReader(t)
          conditions <- obj.readOpt[Seq[io.k8s.api.core.v1.ComponentCondition]]("conditions")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
      } yield ComponentStatus (
          conditions = conditions,
          metadata = metadata
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.5.1-sources.jar: io/k8s/api/core/v1/ComponentStatus.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** ComponentStatus (and ComponentStatusList) holds the cluster validation info. Deprecated: This API is deprecated in v1.19+ */
final case class ComponentStatus(
  conditions : Option[Seq[io.k8s.api.core.v1.ComponentCondition]] = None,
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("", "ComponentStatus", "v1")


  /** Returns a new data with conditions set to new value */
  def withConditions(value: Seq[io.k8s.api.core.v1.ComponentCondition]) : ComponentStatus = copy(conditions = Some(value))
  /** Appends new values to conditions */
  def addConditions(newValues: io.k8s.api.core.v1.ComponentCondition*) : ComponentStatus = copy(conditions = Some(conditions.fold(newValues)(_ ++ newValues)))
  /** if conditions has a value, transforms to the result of function*/
  def mapConditions(f: Seq[io.k8s.api.core.v1.ComponentCondition] => Seq[io.k8s.api.core.v1.ComponentCondition]) : ComponentStatus = copy(conditions = conditions.map(f))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : ComponentStatus = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : ComponentStatus = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = ComponentStatus.encoder.apply(this)
}

object ComponentStatus {

    implicit val encoder : Encoder[io.k8s.api.core.v1.ComponentStatus] = new Encoder[io.k8s.api.core.v1.ComponentStatus] {
        def apply[T : Builder](o: io.k8s.api.core.v1.ComponentStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("conditions", o.conditions)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[ComponentStatus] = new Decoder[ComponentStatus] {
      def apply[T : Reader](t: T): Either[String, ComponentStatus] = for {
          obj <- ObjectReader(t)
          conditions <- obj.readOpt[Seq[io.k8s.api.core.v1.ComponentCondition]]("conditions")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
      } yield ComponentStatus (
          conditions = conditions,
          metadata = metadata
        )
    }
}
